@@ -25,25 +25,25 @@
 #include <config.h>
 #endif
 
+#include "glade-project-window.h"
+
+#include <gladeui/glade.h>
+#include <gladeui/glade-design-view.h>
+#include <gladeui/glade-binding.h>
+
 #include <string.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkstock.h>
 
-#include "glade.h"
-#include "glade-paths.h"
-#include "glade-design-view.h"
-#include "glade-project-window.h"
-#include "glade-binding.h"
-
 #define GLADE_ACTION_GROUP_STATIC "GladeStatic"
 #define GLADE_ACTION_GROUP_PROJECT "GladeProject"
 #define GLADE_ACTION_GROUP_PROJECTS_LIST_MENU "GladeProjectsList"
 
 #define READONLY_INDICATOR (_("[Read Only]"))
 
-#define GLADE_URL_USER_MANUAL      "http://glade.gnome.org/doc/manual"
+#define GLADE_URL_USER_MANUAL      "http://glade.gnome.org/manual/index.html"
 #define GLADE_URL_DEVELOPER_MANUAL "http://glade.gnome.org/docs/index.html"
 
 #define GLADE_PROJECT_WINDOW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object),  \
@@ -76,8 +76,6 @@ struct _GladeProjectWindowPrivate
 	GtkRecentManager *recent_manager;
 	GtkWidget *recent_menu;
 
-	GtkWidget *console;
-
 	gchar *default_path; /* the default path for open/save operations */
 	
 	GtkToggleToolButton *selector_button; /* the widget selector button (replaces the one in the palette) */
@@ -103,22 +101,22 @@ about_dialog_activate_link_func (GtkAboutDialog *dialog, const gchar *link, Glad
 	
 	if (!retval)
 	{
-		warning_dialog = gtk_message_dialog_new (GTK_WINDOW (gpw->priv->window),
-						 GTK_DIALOG_MODAL,
-						 GTK_MESSAGE_WARNING,
-						 GTK_BUTTONS_OK,
-						 _("Could not display the URL '%s'"),
-						 link);
+		warning_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
+							 GTK_DIALOG_MODAL,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_OK,
+							 _("Could not display the URL '%s'"),
+							 link);
 						 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (warning_dialog),
-							  _("No suitable web browser executable could be found."));
+							  _("No suitable web browser could be found."));
 						 	
 		gtk_window_set_title (GTK_WINDOW (warning_dialog), "");
-
+		
 		g_signal_connect_swapped (warning_dialog, "response",
 					  G_CALLBACK (gtk_widget_destroy),
-					  dialog);
-
+					  warning_dialog);
+				
 		gtk_widget_show (warning_dialog);
 	}	
 
@@ -188,6 +186,187 @@ glade_project_window_help_show (const gchar *link_id)
 	return retval && !exit_status;
 }
 
+
+/* the following functions are taken from gedit-utils.c */
+
+static gchar *
+str_middle_truncate (const gchar *string,
+		     guint        truncate_length)
+{
+	GString     *truncated;
+	guint        length;
+	guint        n_chars;
+	guint        num_left_chars;
+	guint        right_offset;
+	guint        delimiter_length;
+	const gchar *delimiter = "\342\200\246";
+
+	g_return_val_if_fail (string != NULL, NULL);
+
+	length = strlen (string);
+
+	g_return_val_if_fail (g_utf8_validate (string, length, NULL), NULL);
+
+	/* It doesnt make sense to truncate strings to less than
+	 * the size of the delimiter plus 2 characters (one on each
+	 * side)
+	 */
+	delimiter_length = g_utf8_strlen (delimiter, -1);
+	if (truncate_length < (delimiter_length + 2)) {
+		return g_strdup (string);
+	}
+
+	n_chars = g_utf8_strlen (string, length);
+
+	/* Make sure the string is not already small enough. */
+	if (n_chars <= truncate_length) {
+		return g_strdup (string);
+	}
+
+	/* Find the 'middle' where the truncation will occur. */
+	num_left_chars = (truncate_length - delimiter_length) / 2;
+	right_offset = n_chars - truncate_length + num_left_chars + delimiter_length;
+
+	truncated = g_string_new_len (string,
+				      g_utf8_offset_to_pointer (string, num_left_chars) - string);
+	g_string_append (truncated, delimiter);
+	g_string_append (truncated, g_utf8_offset_to_pointer (string, right_offset));
+		
+	return g_string_free (truncated, FALSE);
+}
+
+/*
+ * Doubles underscore to avoid spurious menu accels - taken from gedit-utils.c
+ */
+static gchar * 
+escape_underscores (const gchar* text,
+		    gssize       length)
+{
+	GString *str;
+	const gchar *p;
+	const gchar *end;
+
+	g_return_val_if_fail (text != NULL, NULL);
+
+	if (length < 0)
+		length = strlen (text);
+
+	str = g_string_sized_new (length);
+
+	p = text;
+	end = text + length;
+
+	while (p != end)
+	{
+		const gchar *next;
+		next = g_utf8_next_char (p);
+
+		switch (*p)
+		{
+			case '_':
+				g_string_append (str, "__");
+				break;
+			default:
+				g_string_append_len (str, p, next - p);
+				break;
+		}
+
+		p = next;
+	}
+
+	return g_string_free (str, FALSE);
+}
+
+typedef enum
+{
+	FORMAT_NAME_MARK_UNSAVED        = 1 << 0,
+	FORMAT_NAME_ESCAPE_UNDERSCORES  = 1 << 1,
+	FORMAT_NAME_MIDDLE_TRUNCATE     = 1 << 2
+} FormatNameFlags;
+
+#define MAX_TITLE_LENGTH 100
+
+static gchar *
+get_formatted_project_name_for_display (GladeProject *project, FormatNameFlags format_flags)
+{
+	gchar *name, *pass1, *pass2, *pass3;
+	
+	g_return_val_if_fail (project != NULL, NULL);
+	
+	name = glade_project_get_name (project);
+	
+	if ((format_flags & FORMAT_NAME_MARK_UNSAVED)
+	    && glade_project_get_has_unsaved_changes (project))
+		pass1 = g_strdup_printf ("*%s", name);
+	else
+		pass1 = g_strdup (name);
+		
+	if (format_flags & FORMAT_NAME_ESCAPE_UNDERSCORES)
+		pass2 = escape_underscores (pass1, -1);
+	else
+		pass2 = g_strdup (pass1);
+		
+	if (format_flags & FORMAT_NAME_MIDDLE_TRUNCATE)
+		pass3 = str_middle_truncate (pass2, MAX_TITLE_LENGTH);
+	else
+		pass3 = g_strdup (pass2); 
+
+	g_free (name);
+	g_free (pass1);	
+	g_free (pass2);
+	
+	return pass3;
+}
+
+static gchar *
+replace_home_dir_with_tilde (const gchar *path)
+{
+#ifdef G_OS_UNIX
+	gchar *tmp;
+	gchar *home;
+
+	g_return_val_if_fail (path != NULL, NULL);
+
+	/* Note that g_get_home_dir returns a const string */
+	tmp = (gchar *) g_get_home_dir ();
+
+	if (tmp == NULL)
+		return g_strdup (path);
+
+	home = g_filename_to_utf8 (tmp, -1, NULL, NULL, NULL);
+	if (home == NULL)
+		return g_strdup (path);
+
+	if (strcmp (path, home) == 0)
+	{
+		g_free (home);
+		
+		return g_strdup ("~");
+	}
+
+	tmp = home;
+	home = g_strdup_printf ("%s/", tmp);
+	g_free (tmp);
+
+	if (g_str_has_prefix (path, home))
+	{
+		gchar *res;
+
+		res = g_strdup_printf ("~/%s", path + strlen (home));
+
+		g_free (home);
+		
+		return res;		
+	}
+
+	g_free (home);
+
+	return g_strdup (path);
+#else
+	return g_strdup (path);
+#endif
+}
+
 static void
 gpw_refresh_title (GladeProjectWindow *gpw)
 {
@@ -198,20 +377,22 @@ gpw_refresh_title (GladeProjectWindow *gpw)
 	{
 		project = glade_design_view_get_project (gpw->priv->active_view);
 
-		name = glade_project_display_name (project, TRUE, FALSE, FALSE);
+		name = get_formatted_project_name_for_display (project, 
+							       FORMAT_NAME_MARK_UNSAVED |
+							       FORMAT_NAME_MIDDLE_TRUNCATE);
 		
-		if (project->readonly != FALSE)
-			title = g_strdup_printf ("%s %s - %s", name,
-						 READONLY_INDICATOR, g_get_application_name ());
+		if (glade_project_get_readonly (project) != FALSE)
+			title = g_strdup_printf ("%s %s", name, READONLY_INDICATOR);
 		else
-			title = g_strdup_printf ("%s - %s", name,
-						 g_get_application_name ());
+			title = g_strdup_printf ("%s", name);
 		
 		g_free (name);
 	}
 	else
-		title = g_strdup_printf ("%s", g_get_application_name ());
-
+	{
+		title = g_strdup (_("User Interface Designer"));
+	}
+	
 	gtk_window_set_title (GTK_WINDOW (gpw->priv->window), title);
 
 	g_free (title);
@@ -228,9 +409,9 @@ update_default_path (GladeProjectWindow *gpw, GladeProject *project)
 {
 	gchar *path;
 	
-	g_return_if_fail (project->path != NULL);
+	g_return_if_fail (glade_project_get_path (project) != NULL);
 
-	path = g_path_get_dirname (project->path);
+	path = g_path_get_dirname (glade_project_get_path (project));
 
 	g_free (gpw->priv->default_path);
 	gpw->priv->default_path = g_strdup (path);
@@ -331,7 +512,7 @@ project_selection_changed_cb (GladeProject *project, GladeProjectWindow *gpw)
 		
 			glade_widget = glade_widget_get_from_gobject (G_OBJECT (list->data));
 			
-			text = g_strdup_printf ("%s [%s] - Properties",
+			text = g_strdup_printf (_("%s [%s] - Properties"),
 						glade_widget_get_name (glade_widget),
 						G_OBJECT_TYPE_NAME (glade_widget->object));
 					
@@ -341,7 +522,7 @@ project_selection_changed_cb (GladeProject *project, GladeProjectWindow *gpw)
 		}	
 		else
 		{
-			gtk_label_set_text (label, "Properties");
+			gtk_label_set_text (label, _("Properties"));
 		}
 			
 	}
@@ -356,26 +537,57 @@ glade_project_window_get_active_view (GladeProjectWindow *gpw)
 	return gpw->priv->active_view;
 }
 
+static gchar *
+format_project_list_item_tooltip (GladeProject *project)
+{
+	gchar *tooltip, *path, *name;
+
+	if (glade_project_get_path (project))
+	{
+		path = replace_home_dir_with_tilde (glade_project_get_path (project));
+		
+		if (glade_project_get_readonly (project))
+		{
+			tooltip = g_strdup_printf ("Activate '%s' %s",
+					   	   path,
+					   	   READONLY_INDICATOR);
+		}
+		else
+		{
+			tooltip = g_strdup_printf ("Activate '%s'", path);		
+		}
+		g_free (path);
+	}
+	else
+	{
+		name = glade_project_get_name (project);
+		tooltip = g_strdup_printf ("Activate '%s'", name);
+		g_free (name);
+	}
+	
+	return tooltip;
+}
+
 static void
 gpw_refresh_projects_list_item (GladeProjectWindow *gpw, GladeProject *project)
 {
 	GtkAction *action;
 	gchar *project_name;
-	gchar *tooltip = NULL;
+	gchar *tooltip;
 	
 	/* Get associated action */
 	action = GTK_ACTION (g_object_get_data (G_OBJECT (project), "project-list-action"));
 
 	/* Set action label */
-	project_name = glade_project_display_name (project, TRUE, FALSE, TRUE);
+	project_name = get_formatted_project_name_for_display (project,
+							       FORMAT_NAME_MARK_UNSAVED |
+							       FORMAT_NAME_ESCAPE_UNDERSCORES |
+							       FORMAT_NAME_MIDDLE_TRUNCATE);
+							
 	g_object_set (action, "label", project_name, NULL);
 
 	/* Set action tooltip */
-	if (project->readonly != FALSE && project->path)
-		tooltip = g_strdup_printf ("%s %s", project->path, READONLY_INDICATOR);
-	else if (project->path)
-		tooltip = g_strdup_printf ("%s", project->path);
-	
+	tooltip = format_project_list_item_tooltip (project);
 	g_object_set (action, "tooltip", tooltip, NULL);
 	
 	g_free (tooltip);
@@ -590,7 +802,6 @@ gpw_refresh_projects_list_menu (GladeProjectWindow *window)
 		GtkRadioAction *action;
 		gchar *action_name;
 		gchar *project_name;
-		gchar *name;
 		gchar *tooltip;
 		gchar *accel;
 
@@ -606,15 +817,19 @@ gpw_refresh_projects_list_menu (GladeProjectWindow *window)
 		 * get the same accel.
 		 */
 		action_name = g_strdup_printf ("Tab_%d", i);
-		project_name = glade_project_display_name (project, TRUE, FALSE, FALSE);
-		name = glade_util_duplicate_underscores (project_name);
-		tooltip =  g_strdup_printf (_("Activate %s"), project_name);
+		project_name = get_formatted_project_name_for_display (project,
+								       FORMAT_NAME_MARK_UNSAVED |
+								       FORMAT_NAME_MIDDLE_TRUNCATE |
+								       FORMAT_NAME_ESCAPE_UNDERSCORES);				       
+		tooltip = format_project_list_item_tooltip (project);
+		
+
 
 		/* alt + 1, 2, 3... 0 to switch to the first ten tabs */
 		accel = (i < 10) ? g_strdup_printf ("<alt>%d", (i + 1) % 10) : NULL;
 
 		action = gtk_radio_action_new (action_name, 
-					       name,
+					       project_name,
 					       tooltip, 
 					       NULL,
 					       i);
@@ -650,7 +865,6 @@ gpw_refresh_projects_list_menu (GladeProjectWindow *window)
 
 		g_free (action_name);
 		g_free (project_name);
-		g_free (name);
 		g_free (tooltip);
 		g_free (accel);
 	}
@@ -760,7 +974,7 @@ gpw_save (GladeProjectWindow *gpw, GladeProject *project, const gchar *path)
 	gint       response;
 
 	/* check for external modification to the project file */
-	mtime = glade_util_get_file_mtime (project->path, NULL);
+	mtime = glade_util_get_file_mtime (glade_project_get_path (project), NULL);
 	
 	if (mtime > glade_project_get_file_mtime (project)) {
 	
@@ -769,7 +983,7 @@ gpw_save (GladeProjectWindow *gpw, GladeProject *project, const gchar *path)
 						 GTK_MESSAGE_WARNING,
 						 GTK_BUTTONS_NONE,
 						 _("The file %s has been modified since reading it"),
-						 project->path);
+						 glade_project_get_path (project));
 						 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), 				 
 							  _("If you save it, all the external changes could be lost. Save it anyway?"));
@@ -799,7 +1013,7 @@ gpw_save (GladeProjectWindow *gpw, GladeProject *project, const gchar *path)
 	}
 		  
 	/* Interestingly; we cannot use `path' after glade_project_reset_path
-	 * because we are getting called with project->path as an argument.
+	 * because we are getting called with glade_project_get_path (project) as an argument.
 	 */
 	if (!glade_project_save (project, path, &error))
 	{
@@ -816,9 +1030,9 @@ gpw_save (GladeProjectWindow *gpw, GladeProject *project, const gchar *path)
 	glade_app_update_instance_count (project);
 
 	/* Get display_name here, it could have changed with "Save As..." */
-	display_name = glade_project_display_name (project, FALSE, FALSE, FALSE);
+	display_name = glade_project_get_name (project);
 
-	gpw_recent_add (gpw, project->path);
+	gpw_recent_add (gpw, glade_project_get_path (project));
 	update_default_path (gpw, project);
 
 	/* refresh names */
@@ -839,7 +1053,7 @@ gpw_save_as (GladeProjectWindow *gpw)
  	GladeProject *project, *another_project;
  	GtkWidget *filechooser;
 	gchar *path = NULL;
-	gchar *real_path, *ch;
+	gchar *real_path, *ch, *project_name;
 	
 	project = glade_design_view_get_project (gpw->priv->active_view);
 	
@@ -854,9 +1068,9 @@ gpw_save_as (GladeProjectWindow *gpw)
 						  GTK_WINDOW (gpw->priv->window),
 						  GLADE_FILE_DIALOG_ACTION_SAVE);
 
-	if (project->path)
+	if (glade_project_get_path (project))
 	{
-		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (filechooser), project->path);
+		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (filechooser), glade_project_get_path (project));
 	}
 	else	
 	{
@@ -867,7 +1081,9 @@ gpw_save_as (GladeProjectWindow *gpw)
 			g_free (default_path);
 		}
 
-		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (filechooser), project->name);
+		project_name = glade_project_get_name (project);
+		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (filechooser), project_name);
+		g_free (project_name);
 	}
 	
  	if (gtk_dialog_run (GTK_DIALOG(filechooser)) == GTK_RESPONSE_OK)
@@ -933,9 +1149,9 @@ gpw_save_cb (GtkAction *action, GladeProjectWindow *gpw)
 		return;
 	}
 
-	if (project->path != NULL) 
+	if (glade_project_get_path (project) != NULL) 
 	{
-		gpw_save (gpw, project, project->path);
+		gpw_save (gpw, project, glade_project_get_path (project));
  		return;
 	}
 
@@ -953,12 +1169,14 @@ gpw_confirm_close_project (GladeProjectWindow *gpw, GladeProject *project)
 {
 	GtkWidget *dialog;
 	gboolean close = FALSE;
-	gchar *msg;
+	gchar *msg, *project_name = NULL;
 	gint ret;
 	GError *error = NULL;
 
+	project_name = glade_project_get_name (project);
+
 	msg = g_strdup_printf (_("<span weight=\"bold\" size=\"larger\">Save changes to project \"%s\" before closing?</span>\n\n"
-				 "Your changes will be lost if you don't save them.\n"), project->name);
+				 "Your changes will be lost if you don't save them.\n"), project_name);
 
 	dialog = gtk_message_dialog_new (GTK_WINDOW (gpw->priv->window),
 					 GTK_DIALOG_MODAL,
@@ -984,16 +1202,16 @@ gpw_confirm_close_project (GladeProjectWindow *gpw, GladeProject *project)
 		 * since it saves the current project, while the modified 
                  * project we are saving may be not the current one.
 		 */
-		if (project->path != NULL)
+		if (glade_project_get_path (project) != NULL)
 		{
 			if ((close = glade_project_save
-			     (project, project->path, &error)) == FALSE)
+			     (project, glade_project_get_path (project), &error)) == FALSE)
 			{
 
 				glade_util_ui_message
 					(gpw->priv->window, GLADE_UI_ERROR, 
 					 _("Failed to save %s to %s: %s"),
-					 project->name, project->path, error->message);
+					 project_name, glade_project_get_path (project), error->message);
 				g_error_free (error);
 			}
 		}
@@ -1016,7 +1234,7 @@ gpw_confirm_close_project (GladeProjectWindow *gpw, GladeProject *project)
 			}
 
 			gtk_file_chooser_set_current_name
-				(GTK_FILE_CHOOSER (filechooser), project->name);
+				(GTK_FILE_CHOOSER (filechooser), project_name);
 
 			
 			if (gtk_dialog_run (GTK_DIALOG(filechooser)) == GTK_RESPONSE_OK)
@@ -1046,6 +1264,7 @@ gpw_confirm_close_project (GladeProjectWindow *gpw, GladeProject *project)
 		close = FALSE;
 	}
 
+	g_free (project_name);
 	gtk_widget_destroy (dialog);
 	return close;
 }
@@ -1078,7 +1297,7 @@ gpw_close_cb (GtkAction *action, GladeProjectWindow *gpw)
 	if (view == NULL)
 		return;
 
-	if (project->changed)
+	if (glade_project_get_has_unsaved_changes (project))
 	{
 		close = gpw_confirm_close_project (gpw, project);
 			if (!close)
@@ -1096,7 +1315,7 @@ gpw_quit_cb (GtkAction *action, GladeProjectWindow *gpw)
 	{
 		GladeProject *project = GLADE_PROJECT (list->data);
 
-		if (project->changed)
+		if (glade_project_get_has_unsaved_changes (project))
 		{
 			gboolean quit = gpw_confirm_close_project (gpw, project);
 			if (!quit)
@@ -1172,48 +1391,6 @@ gpw_hide_window_on_delete (GtkWidget *window, gpointer not_used, GtkUIManager *u
 	return TRUE;
 }
 
-static void
-gpw_construct_console (GladeProjectWindow *gpw)
-{
-	GtkWidget *window, *console, *notebook;
-	GList *list, *l;
-	
-	g_return_if_fail (gpw != NULL);
-
-	window = gpw->priv->console = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
-	gtk_window_set_title (GTK_WINDOW (window), _("Glade's Script Console"));
-	gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
-	gtk_widget_set_size_request (window, 640, 480);
-	
-	notebook = gtk_notebook_new ();
-	gtk_container_add (GTK_CONTAINER (window), notebook);
-	gtk_widget_show (notebook);
-	
-	for (list = l = glade_binding_get_all(); l && l->data; l = g_list_next (l))
-	{
-		GladeBinding *binding = l->data;
-		
-		if ((console = glade_binding_console_new (binding)))
-		{
-			gtk_notebook_append_page (GTK_NOTEBOOK (notebook), console,
-						  gtk_label_new (glade_binding_get_name (binding)));
-			gtk_widget_show (console);
-		}
-	}
-
-	if (list == NULL)
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget 
-					  (gpw->priv->ui, "/MenuBar/ViewMenu/Console"),
-					  FALSE);
-
-	g_list_free (list);
-	
-	/* Delete event, don't destroy it */
-	g_signal_connect (window, "delete-event",
-			  G_CALLBACK (gpw_hide_window_on_delete), gpw->priv->ui);
-}
-
 static void
 gpw_doc_search_cb (GladeEditor        *editor,
 		   const gchar        *book,
@@ -1280,16 +1457,6 @@ gpw_notebook_switch_page_cb (GtkNotebook *notebook,
 
 }
 
-static void
-gpw_show_console_cb (GtkAction *action, GladeProjectWindow *gpw)
-{
-	g_return_if_fail (gpw != NULL);
-
-	gtk_widget_show (gpw->priv->console);
-
-	gtk_window_present (GTK_WINDOW (gpw->priv->console));
-}
-
 static void
 gpw_notebook_tab_added_cb (GtkNotebook *notebook,
 			   GladeDesignView *view,
@@ -1532,44 +1699,19 @@ gpw_about_cb (GtkAction *action, GladeProjectWindow *gpw)
 		  "Vincent Geddes <vincent.geddes@gmail.com>",
 		  NULL };
 
-	static const gchar translators[] =
-		"Fatih Demir <kabalak@gtranslator.org>\n"
-		"Christian Rose <menthos@menthos.com>\n"
-		"Pablo Saratxaga <pablo@mandrakesoft.com>\n"
-		"Duarte Loreto <happyguy_pt@hotmail.com>\n"
-		"Zbigniew Chyla <cyba@gnome.pl>\n"
-		"Hasbullah Bin Pit <sebol@ikhlas.com>\n"
-		"Takeshi AIHANA <aihana@gnome.gr.jp>\n"
-		"Kjartan Maraas <kmaraas@gnome.org>\n"
-		"Carlos Perell Marn <carlos@gnome-db.org>\n"
-		"Valek Filippov <frob@df.ru>\n"
-		"Stanislav Visnovsky <visnovsky@nenya.ms.mff.cuni.cz>\n"
-		"Christophe Merlet <christophe@merlet.net>\n"
-		"Funda Wang <fundawang@linux.net.cn>\n"
-		"Francisco Javier F. Serrador <serrador@cvs.gnome.org>\n"
-		"Adam Weinberger <adamw@gnome.org>\n"
-		"Raphael Higino <raphaelh@cvs.gnome.org>\n"
-		"Clytie Siddall <clytie@riverland.net.au>\n"
-		"Jordi Mas <jmas@softcatala.org>\n"
-		"Vincent van Adrighem <adrighem@gnome.org>\n"
-		"Daniel Nylander <po@danielnylander.se>\n";
-
-	static const gchar comments[] =
-		N_("Glade is a user interface designer for GTK+ and GNOME.\n"
-		  "This version is a rewrite of the Glade 2 version, "
-		  "originally created by Damon Chaplin\n");
-
 	static const gchar license[] =
-		N_("This program is free software; you can redistribute it and/or modify\n"
-		  "it under the terms of the GNU General Public License as\n"
-		  "published by the Free Software Foundation; either version 2 of the\n"
-		  "License, or (at your option) any later version.\n\n"
-		  "This program is distributed in the hope that it will be useful,\n"
-		  "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-		  "GNU General Public License for more details.\n\n"
-		  "You should have received a copy of the GNU General Public License\n"
-		  "along with this program; if not, write to the Free Software\n"
+		N_("Glade is free software; you can redistribute it and/or modify "
+		  "it under the terms of the GNU General Public License as "
+		  "published by the Free Software Foundation; either version 2 of the "
+		  "License, or (at your option) any later version."
+		  "\n\n"
+		  "Glade is distributed in the hope that it will be useful, "
+		  "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+		  "GNU General Public License for more details."
+		  "\n\n"
+		  "You should have received a copy of the GNU General Public License "
+		  "along with Glade; if not, write to the Free Software "
 		  "Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
 		  "MA 02110-1301, USA.");
 
@@ -1582,9 +1724,10 @@ gpw_about_cb (GtkAction *action, GladeProjectWindow *gpw)
 			       "name", g_get_application_name (),
 			       "logo-icon-name", "glade-3",
 			       "authors", authors,
-			       "translator-credits", translators,
-			       "comments", comments,
-			       "license", license,
+			       "translator-credits", _("translator-credits"),
+			       "comments", _("A user interface designer for GTK+ and GNOME."),
+			       "license", _(license),
+			       "wrap-license", TRUE,
 			       "copyright", copyright,
 			       "version", PACKAGE_VERSION,
 			       "website", "http://glade.gnome.org",
@@ -1616,7 +1759,6 @@ static const gchar *ui_info =
 "    </menu>\n"
 "    <menu action='ViewMenu'>\n"
 "      <menuitem action='Clipboard'/>\n"
-"      <menuitem action='Console'/>\n"
 "      <separator/>\n"
 "      <menu action='PaletteAppearance'>\n"
 "        <menuitem action='IconsAndLabels'/>\n"
@@ -1662,61 +1804,62 @@ static GtkActionEntry static_entries[] = {
 	{ "HelpMenu", NULL, N_("_Help") },
 	
 	/* FileMenu */
-	{ "New", GTK_STOCK_NEW, N_("_New"), "<control>N",
+	{ "New", GTK_STOCK_NEW, NULL, "<control>N",
 	  N_("Create a new project"), G_CALLBACK (gpw_new_cb) },
 	
-	{ "Open", GTK_STOCK_OPEN, N_("_Open"),"<control>O",
+	{ "Open", GTK_STOCK_OPEN, N_("_Open\342\200\246") ,"<control>O",
 	  N_("Open a project"), G_CALLBACK (gpw_open_cb) },
 
 	{ "OpenRecent", NULL, N_("Open _Recent") },	
 	
-	{ "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
+	{ "Quit", GTK_STOCK_QUIT, NULL, "<control>Q",
 	  N_("Quit the program"), G_CALLBACK (gpw_quit_cb) },
 
 	/* ViewMenu */
-	{ "PaletteAppearance", NULL, "Palette _Appearance" },
+	{ "PaletteAppearance", NULL, N_("Palette _Appearance") },
 	
 	/* HelpMenu */
-	{ "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
+	{ "About", GTK_STOCK_ABOUT, NULL, NULL,
 	  N_("About this application"), G_CALLBACK (gpw_about_cb) },
 
-	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	{ "HelpContents", GTK_STOCK_HELP, NULL, "F1",
 	  N_("Display the user manual"), G_CALLBACK (gpw_show_help_cb) },
 
 	{ "DeveloperReference", NULL, N_("_Developer Reference"), NULL,
 	  N_("Display the developer reference manual"), G_CALLBACK (gpw_show_developer_manual_cb) }
 };
+
 static guint n_static_entries = G_N_ELEMENTS (static_entries);
 
 static GtkActionEntry project_entries[] = {
 
 	/* FileMenu */
-	{ "Save", GTK_STOCK_SAVE, N_("_Save"),"<control>S",
+	{ "Save", GTK_STOCK_SAVE, NULL, "<control>S",
 	  N_("Save the current project"), G_CALLBACK (gpw_save_cb) },
 	
 	{ "SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As\342\200\246"), NULL,
 	  N_("Save the current project with a different name"), G_CALLBACK (gpw_save_as_cb) },
 	
-	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
+	{ "Close", GTK_STOCK_CLOSE, NULL, "<control>W",
 	  N_("Close the current project"), G_CALLBACK (gpw_close_cb) },
 
 	/* EditMenu */	
-	{ "Undo", GTK_STOCK_UNDO, N_("_Undo"), "<control>Z",
+	{ "Undo", GTK_STOCK_UNDO, NULL, "<control>Z",
 	  N_("Undo the last action"),	G_CALLBACK (gpw_undo_cb) },
 	
-	{ "Redo", GTK_STOCK_REDO, N_("_Redo"), "<control>R",
+	{ "Redo", GTK_STOCK_REDO, NULL, "<shift><control>Z",
 	  N_("Redo the last action"),	G_CALLBACK (gpw_redo_cb) },
 	
-	{ "Cut", GTK_STOCK_CUT, N_("C_ut"), NULL,
+	{ "Cut", GTK_STOCK_CUT, NULL, NULL,
 	  N_("Cut the selection"), G_CALLBACK (gpw_cut_cb) },
 	
-	{ "Copy", GTK_STOCK_COPY, N_("_Copy"), NULL,
+	{ "Copy", GTK_STOCK_COPY, NULL, NULL,
 	  N_("Copy the selection"), G_CALLBACK (gpw_copy_cb) },
 	
-	{ "Paste", GTK_STOCK_PASTE, N_("_Paste"), NULL,
+	{ "Paste", GTK_STOCK_PASTE, NULL, NULL,
 	  N_("Paste the clipboard"), G_CALLBACK (gpw_paste_cb) },
 	
-	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), "Delete",
+	{ "Delete", GTK_STOCK_DELETE, NULL, "Delete",
 	  N_("Delete the selection"), G_CALLBACK (gpw_delete_cb) },
 
 	/* ViewMenu */
@@ -1725,10 +1868,6 @@ static GtkActionEntry project_entries[] = {
 	  N_("Show the clipboard"),
 	  G_CALLBACK (gpw_show_clipboard_cb) },
 	  
-	{ "Console", NULL, N_("C_onsole"), NULL,
-	  N_("Show Script-do console"),
-	  G_CALLBACK (gpw_show_console_cb) },
-	  
 	/* ProjectsMenu */
 	{ "PreviousProject", NULL, N_("_Previous Project"), "<control>Page_Up",
 	  N_("Activate previous project"), G_CALLBACK (glade_project_window_previous_project_cb) },
@@ -1958,7 +2097,7 @@ create_selector_tool_button (GtkToolbar *toolbar)
 	GtkWidget    *image;
 	gchar        *image_path;
 	
-	image_path = g_build_filename (glade_pixmaps_dir, "selector.png", NULL);
+	image_path = g_build_filename (glade_app_get_pixmaps_dir (), "selector.png", NULL);
 	image = gtk_image_new_from_file (image_path);
 	g_free (image_path);
 	
@@ -1966,10 +2105,11 @@ create_selector_tool_button (GtkToolbar *toolbar)
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (button), TRUE);
 	
 	gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (button), image);
+	gtk_tool_button_set_label (GTK_TOOL_BUTTON (button), _("Select Widgets"));
 	
 	gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (button),
 				   toolbar->tooltips,
-				   _("Select a widget"),
+				   _("Select widgets in the workspace"),
 				   NULL);
 	
 	gtk_widget_show (GTK_WIDGET (button));
@@ -1978,6 +2118,24 @@ create_selector_tool_button (GtkToolbar *toolbar)
 	return GTK_WIDGET (button);
 }
 
+static gint
+gpw_hijack_editor_key_press (GtkWidget          *win, 
+			     GdkEventKey        *event, 
+			     GladeProjectWindow *gpw)
+{
+	if (GTK_WINDOW (win)->focus_widget &&
+	    (event->keyval == GDK_Delete || /* Filter Delete from accelerator keys */
+	     ((event->state & GDK_CONTROL_MASK) && /* CNTL keys... */
+	      ((event->keyval == GDK_c || event->keyval == GDK_C) || /* CNTL-C (copy)  */
+	       (event->keyval == GDK_x || event->keyval == GDK_X) || /* CNTL-X (cut)   */
+	       (event->keyval == GDK_v || event->keyval == GDK_V))))) /* CNTL-V (paste) */
+	{
+		return gtk_widget_event (GTK_WINDOW (win)->focus_widget, 
+					 (GdkEvent *)event);
+	}
+	return FALSE;
+}
+
 static void
 glade_project_window_create (GladeProjectWindow *gpw)
 {
@@ -2081,9 +2239,6 @@ glade_project_window_create (GladeProjectWindow *gpw)
 
 	gtk_widget_set_sensitive (editor_item, FALSE);
 	
-	/* Console */
-	gpw_construct_console (gpw);
-	
 	/* recent files */	
 	gpw->priv->recent_manager = gtk_recent_manager_get_for_screen (gtk_widget_get_screen (gpw->priv->window));
 
@@ -2148,6 +2303,10 @@ glade_project_window_create (GladeProjectWindow *gpw)
 	g_signal_connect (gpw->priv->window, "window-state-event",
 			  G_CALLBACK (gpw_window_state_event_cb),
 			  gpw);
+
+	g_signal_connect (G_OBJECT (gpw->priv->window), "key-press-event",
+			  G_CALLBACK (gpw_hijack_editor_key_press), gpw);
+
 }
 
 static void
@@ -2172,7 +2331,7 @@ glade_project_window_new_project (GladeProjectWindow *gpw)
 {
 	GladeProject *project;
 
-	project = glade_project_new (TRUE);
+	project = glade_project_new ();
 	if (!project)
 	{
 		glade_util_ui_message (gpw->priv->window, 
@@ -2200,12 +2359,12 @@ glade_project_window_open_project (GladeProjectWindow *gpw, const gchar *path)
 		return TRUE; /* let this pass */
 	}
 	
-	if ((project = glade_project_open (path)) == NULL)
+	if ((project = glade_project_load (path)) == NULL)
 		return FALSE;
 
 	glade_project_window_add_project (gpw, project);
 	
-	gpw_recent_add (gpw, project->path);
+	gpw_recent_add (gpw, glade_project_get_path (project));
 	update_default_path (gpw, project);
 	
 	return TRUE;
